@@ -185,7 +185,9 @@ class AnimationGroup(Animation):
         else:
             sub_alphas[(sub_alphas > 1) | with_zero_run_time] = 1
 
-        for anim_to_update, sub_alpha in zip(to_update["anim"], sub_alphas):
+        for anim_to_update, sub_alpha in zip(
+            to_update["anim"], sub_alphas, strict=False
+        ):
             anim_to_update.interpolate(sub_alpha)
 
         self.anim_group_time = anim_group_time
