@@ -2,14 +2,9 @@
 
 from __future__ import annotations
 
-import sys
+from importlib.metadata import entry_points
 from typing import Any
 
-if sys.version_info < (3, 10):
-    from importlib_metadata import entry_points
-else:
-    from importlib.metadata import entry_points
-
 from manim._config import console
 
 __all__ = ["list_plugins"]
